@@ -1,7 +1,7 @@
 import unittest
 import pandas as pd
 import numpy as np
-from bcselector.datasets import discretize, load_mimic3, load_hepatitis
+from bcselector.datasets import _discretize, load_sample, load_hepatitis
 
 
 class TestDiscretization(unittest.TestCase):
@@ -9,60 +9,48 @@ class TestDiscretization(unittest.TestCase):
         # Given
         x = np.random.normal(0, 1, 1000)
         # When
-        x_discretized = discretize(x, n_bins=20)
+        x_discretized = _discretize(x, n_bins=20)
         # Then
         assert len(np.unique(x_discretized)) == 20
 
 
-class TestMIMIC3(unittest.TestCase):
+class TestSampleData(unittest.TestCase):
     def test_loading_data(self):
         # Given
         # When
-        load_mimic3()
+        load_sample()
 
         # Then
     def test_data_shape(self):
         # Given
         # When
-        X, y, costs = load_mimic3()
+        X, y, costs = load_sample()
 
         # Then
-        assert X.shape == (6591, 306)
-        assert y.shape == (6591, 10)
-        assert len(costs) == 306
+        assert X.shape == (10000, 35)
+        assert y.shape == (10000, )
+        assert len(costs) == 35
 
     def test_data_type_frame(self):
         # Given
         # When
-        X, y, costs = load_mimic3()
+        X, y, costs = load_sample()
 
         # Then
         assert isinstance(X, pd.DataFrame)
-        assert isinstance(y, pd.DataFrame)
+        assert isinstance(y, pd.Series)
         assert isinstance(costs, dict)
 
     def test_data_type_array(self):
         # Given
         # When
-        X, y, costs = load_mimic3(as_frame=False)
+        X, y, costs = load_sample(as_frame=False)
 
         # Then
         assert isinstance(X, np.ndarray)
         assert isinstance(y, np.ndarray)
         assert isinstance(costs, list)
 
-    def test_data_discretization(self):
-        # Given
-        # When
-        X1, y1, costs1 = load_mimic3(as_frame=False, discretize_data=False)
-        X2, y2, costs2 = load_mimic3(as_frame=False, n_bins=20)
-
-        # Then
-        assert not np.array_equal(X1, X2)
-        assert np.array_equal(y1, y2)
-        assert costs1 == costs2
-        assert len(np.unique(X1[:, 0])) > len(np.unique(X2[:, 0]))
-
 
 class TestHepatitis(unittest.TestCase):
     def test_loading_data(self):
@@ -78,7 +66,7 @@ class TestHepatitis(unittest.TestCase):
 
         # Then
         assert X.shape == (155, 19)
-        assert y.shape == (155, 1)
+        assert y.shape == (155, )
         assert len(costs) == 19
 
     def test_data_type_frame(self):
@@ -104,11 +92,29 @@ class TestHepatitis(unittest.TestCase):
     def test_data_discretization(self):
         # Given
         # When
-        X1, y1, costs1 = load_hepatitis(as_frame=False, discretize_data=False)
-        X2, y2, costs2 = load_hepatitis(as_frame=False, n_bins=3)
+        X1, y1, costs1 = load_hepatitis(as_frame=True, discretize_data=False)
+        X2, y2, costs2 = load_hepatitis(as_frame=True, n_bins=10)
 
         # Then
         assert not np.array_equal(X1, X2)
         assert np.array_equal(y1, y2)
         assert costs1 == costs2
-        assert len(np.unique(X1[:, 0])) > len(np.unique(X2[:, 0]))
+        assert len(np.unique(X1.iloc[:, 0])) > len(np.unique(X2.iloc[:, 0]))
+        assert [True if x != 1 else False for x in X1.nunique().values].count(True) / len(X1.nunique().values) == 1
+
+    def test_data_colnames(self):
+        # Given
+        first_colname = 'age'
+        middle_colname = 'spiders'
+        last_colname = 'histology'
+        # When
+        X1, y1, costs1 = load_hepatitis(as_frame=True, discretize_data=False)
+        X2, y2, costs2 = load_hepatitis(as_frame=True, n_bins=10)
+
+        # Then
+        assert X1.columns[0] == first_colname
+        assert X2.columns[0] == first_colname
+        assert X1.columns[10] == middle_colname
+        assert X2.columns[10] == middle_colname
+        assert X1.columns[-1] == last_colname
+        assert X2.columns[-1] == last_colname
